==> legion_0.5.1.orig.tar.gz: legion-0.5.1/db/RepositoryContainer.py <==
"""
LEGION (https://shanewilliamscott.com)
Copyright (c) 2025 Shane William Scott

    This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
    version.

    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
    details.

    You should have received a copy of the GNU General Public License along with this program.
    If not, see <http://www.gnu.org/licenses/>.

Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
"""
from typing import NamedTuple

from db.repositories.CVERepository import CVERepository
from db.repositories.HostRepository import HostRepository
from db.repositories.NoteRepository import NoteRepository
from db.repositories.PortRepository import PortRepository
from db.repositories.ProcessRepository import ProcessRepository
from db.repositories.ScriptRepository import ScriptRepository
from db.repositories.ServiceRepository import ServiceRepository


class RepositoryContainer(NamedTuple):
    serviceRepository: ServiceRepository
    processRepository: ProcessRepository
    hostRepository: HostRepository
    portRepository: PortRepository
    cveRepository: CVERepository
    noteRepository: NoteRepository
    scriptRepository: ScriptRepository

==> legion_0.5.2.orig.tar.gz: legion-0.5.2/db/RepositoryContainer.py <==
"""
LEGION (https://shanewilliamscott.com)
Copyright (c) 2025 Shane William Scott

    This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
    version.

    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
    details.

    You should have received a copy of the GNU General Public License along with this program.
    If not, see <http://www.gnu.org/licenses/>.

Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
"""
from typing import NamedTuple

from db.repositories.CVERepository import CVERepository
from db.repositories.HostRepository import HostRepository
from db.repositories.NoteRepository import NoteRepository
from db.repositories.PortRepository import PortRepository
from db.repositories.ProcessRepository import ProcessRepository
from db.repositories.ScriptRepository import ScriptRepository
from db.repositories.ServiceRepository import ServiceRepository
from db.repositories.CredentialRepository import CredentialRepository


class RepositoryContainer(NamedTuple):
    serviceRepository: ServiceRepository
    processRepository: ProcessRepository
    hostRepository: HostRepository
    portRepository: PortRepository
    cveRepository: CVERepository
    noteRepository: NoteRepository
    scriptRepository: ScriptRepository
    credentialRepository: CredentialRepository
